@@ -4,10 +4,17 @@ from ._version import version_info, __version__  # noqa
 npm_pkg_name = 'jupyter-matplotlib'
 
 
+def _jupyter_labextension_paths():
+    return [{
+        'src': 'labextension',
+        'dest': npm_pkg_name
+    }]
+
+
 def _jupyter_nbextension_paths():
     return [{
         'section': 'notebook',
-        'src': 'static',
+        'src': 'nbextension',
         'dest': npm_pkg_name,
         'require': npm_pkg_name + '/extension'
     }]
