@@ -12,14 +12,15 @@ from traitlets import (
     default
 )
 
+import matplotlib
 from matplotlib import rcParams
-from matplotlib.figure import Figure
 from matplotlib import is_interactive
 from matplotlib.backends.backend_webagg_core import (FigureManagerWebAgg,
                                                      FigureCanvasWebAggCore,
                                                      NavigationToolbar2WebAgg,
                                                      TimerTornado)
-from matplotlib.backend_bases import ShowBase, NavigationToolbar2, cursors
+from matplotlib.backend_bases import NavigationToolbar2, cursors, _Backend
+from matplotlib._pylab_helpers import Gcf
 
 from ._version import js_semver
 
@@ -32,43 +33,6 @@ cursors_str = {
 }
 
 
-class Show(ShowBase):
-
-    def __call__(self, block=None):
-        from matplotlib._pylab_helpers import Gcf
-
-        managers = Gcf.get_all_fig_managers()
-        if not managers:
-            return
-
-        interactive = is_interactive()
-
-        for manager in managers:
-            manager.show()
-
-            # plt.figure adds an event which puts the figure in focus
-            # in the activeQue. Disable this behaviour, as it results in
-            # figures being put as the active figure after they have been
-            # shown, even in non-interactive mode.
-            if hasattr(manager, '_cidgcf'):
-                manager.canvas.mpl_disconnect(manager._cidgcf)
-
-            if not interactive and manager in Gcf._activeQue:
-                Gcf._activeQue.remove(manager)
-
-
-show = Show()
-
-
-def draw_if_interactive():
-    import matplotlib._pylab_helpers as pylab_helpers
-
-    if is_interactive():
-        manager = pylab_helpers.Gcf.get_active()
-        if manager is not None:
-            manager.show()
-
-
 def connection_info():
     """
     Return a string showing the figure and connection status for
@@ -241,6 +205,68 @@ class Canvas(DOMWidget, FigureCanvasWebAggCore):
     def new_timer(self, *args, **kwargs):
         return TimerTornado(*args, **kwargs)
 
+    if matplotlib.__version__ < '3.4':
+        # backport the Python side changes to match the js changes
+        def _handle_key(self, event):
+            _SPECIAL_KEYS_LUT = {'Alt': 'alt',
+                                 'AltGraph': 'alt',
+                                 'CapsLock': 'caps_lock',
+                                 'Control': 'control',
+                                 'Meta': 'meta',
+                                 'NumLock': 'num_lock',
+                                 'ScrollLock': 'scroll_lock',
+                                 'Shift': 'shift',
+                                 'Super': 'super',
+                                 'Enter': 'enter',
+                                 'Tab': 'tab',
+                                 'ArrowDown': 'down',
+                                 'ArrowLeft': 'left',
+                                 'ArrowRight': 'right',
+                                 'ArrowUp': 'up',
+                                 'End': 'end',
+                                 'Home': 'home',
+                                 'PageDown': 'pagedown',
+                                 'PageUp': 'pageup',
+                                 'Backspace': 'backspace',
+                                 'Delete': 'delete',
+                                 'Insert': 'insert',
+                                 'Escape': 'escape',
+                                 'Pause': 'pause',
+                                 'Select': 'select',
+                                 'Dead': 'dead',
+                                 'F1': 'f1',
+                                 'F2': 'f2',
+                                 'F3': 'f3',
+                                 'F4': 'f4',
+                                 'F5': 'f5',
+                                 'F6': 'f6',
+                                 'F7': 'f7',
+                                 'F8': 'f8',
+                                 'F9': 'f9',
+                                 'F10': 'f10',
+                                 'F11': 'f11',
+                                 'F12': 'f12'}
+
+            def handle_key(key):
+                """Handle key values"""
+                value = key[key.index('k') + 1:]
+                if 'shift+' in key:
+                    if len(value) == 1:
+                        key = key.replace('shift+', '')
+                if value in _SPECIAL_KEYS_LUT:
+                    value = _SPECIAL_KEYS_LUT[value]
+                key = key[:key.index('k')] + value
+                return key
+
+            key = handle_key(event['key'])
+            e_type = event['type']
+            guiEvent = event.get('guiEvent', None)
+            if e_type == 'key_press':
+                self.key_press_event(key, guiEvent=guiEvent)
+            elif e_type == 'key_release':
+                self.key_release_event(key, guiEvent=guiEvent)
+        handle_key_press = handle_key_release = _handle_key
+
 
 class FigureManager(FigureManagerWebAgg):
     ToolbarCls = Toolbar
@@ -260,33 +286,47 @@ class FigureManager(FigureManagerWebAgg):
         self.canvas.close()
 
 
-def new_figure_manager(num, *args, **kwargs):
-    """
-    Create a new figure manager instance
-    """
-    figure_class = kwargs.pop('FigureClass', Figure)
-    this_fig = figure_class(*args, **kwargs)
-    return new_figure_manager_given_figure(num, this_fig)
+@_Backend.export
+class _Backend_ipympl(_Backend):
+    FigureCanvas = Canvas
+    FigureManager = FigureManager
 
+    @staticmethod
+    def new_figure_manager_given_figure(num, figure):
+        canvas = Canvas(figure)
+        if 'nbagg.transparent' in rcParams and rcParams['nbagg.transparent']:
+            figure.patch.set_alpha(0)
+        manager = FigureManager(canvas, num)
+        if is_interactive():
+            manager.show()
+            figure.canvas.draw_idle()
 
-def new_figure_manager_given_figure(num, figure):
-    """
-    Create a new figure manager instance for the given figure.
-    """
-    from matplotlib._pylab_helpers import Gcf
+        def destroy(event):
+            canvas.mpl_disconnect(cid)
+            Gcf.destroy(manager)
 
-    def closer(event):
-        Gcf.destroy(num)
+        cid = canvas.mpl_connect('close_event', destroy)
+        return manager
 
-    canvas = Canvas(figure)
-    if 'nbagg.transparent' in rcParams and rcParams['nbagg.transparent']:
-        figure.patch.set_alpha(0)
-    manager = FigureManager(canvas, num)
+    @staticmethod
+    def show(block=None):
+        # TODO: something to do when keyword block==False ?
 
-    if is_interactive():
-        manager.show()
-        figure.canvas.draw_idle()
+        managers = Gcf.get_all_fig_managers()
+        if not managers:
+            return
 
-    canvas.mpl_connect('close_event', closer)
+        interactive = is_interactive()
 
-    return manager
+        for manager in managers:
+            manager.show()
+
+            # plt.figure adds an event which makes the figure in focus the
+            # active one. Disable this behaviour, as it results in
+            # figures being put as the active figure after they have been
+            # shown, even in non-interactive mode.
+            if hasattr(manager, '_cidgcf'):
+                manager.canvas.mpl_disconnect(manager._cidgcf)
+
+            if not interactive:
+                Gcf.figs.pop(manager.num, None)
